==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/GreenIdData.java <==
package com.example.model;

/**
 * Model for GreenIdData
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "GreenIdData", description = "Model for GreenIdData")
@javax.xml.bind.annotation.XmlRootElement(name = "GreenIdData")
public class GreenIdData implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.IndividualResults individualResults = null;
	private java.lang.String overall = null;
	private java.util.List<com.example.model.RegistrationDetails> registrationDetails = null;
	
	/**
	 * Model for IndividualResults
	 */
	public GreenIdData individualResults(com.example.model.IndividualResults individualResults) {
		setIndividualResults(individualResults);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for IndividualResults")
	@com.fasterxml.jackson.annotation.JsonProperty("individualResults")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.IndividualResults getIndividualResults() {
		return this.individualResults;
	}
	public void setIndividualResults(com.example.model.IndividualResults individualResults) {
		this.individualResults = individualResults;
	}
	
	/**
	 */
	public GreenIdData overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	/**
	 */
	public GreenIdData registrationDetails(java.util.List<com.example.model.RegistrationDetails> registrationDetails) {
		setRegistrationDetails(registrationDetails);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("registrationDetails")
	@javax.validation.Valid
	public java.util.List<com.example.model.RegistrationDetails> getRegistrationDetails() {
		return this.registrationDetails;
	}
	public void setRegistrationDetails(java.util.List<com.example.model.RegistrationDetails> registrationDetails) {
		this.registrationDetails = registrationDetails;
	}
	public GreenIdData addRegistrationDetail(com.example.model.RegistrationDetails registrationDetail) {
		if (this.registrationDetails == null) {
			this.registrationDetails = new java.util.ArrayList<com.example.model.RegistrationDetails>();
		}
		this.registrationDetails.add(registrationDetail);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		GreenIdData greenIdData = (GreenIdData) o;
		return java.util.Objects.equals(this.individualResults, greenIdData.individualResults)
				&& java.util.Objects.equals(this.overall, greenIdData.overall)
				&& java.util.Objects.equals(this.registrationDetails, greenIdData.registrationDetails);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.individualResults, this.overall, this.registrationDetails);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class GreenIdData {\n");
		
		sb.append("    individualResults: ").append(toIndentedString(this.individualResults)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("    registrationDetails: ").append(toIndentedString(this.registrationDetails)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/GreenIdData.java <==
package com.example.model;

/**
 * Model for GreenIdData
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "GreenIdData", description = "Model for GreenIdData")
@javax.xml.bind.annotation.XmlRootElement(name = "GreenIdData")
public class GreenIdData implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.IndividualResults individualResults = null;
	private java.lang.String overall = null;
	private java.util.List<com.example.model.RegistrationDetails> registrationDetails = null;
	
	/**
	 * Model for IndividualResults
	 */
	public GreenIdData individualResults(com.example.model.IndividualResults individualResults) {
		setIndividualResults(individualResults);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "individualResults", description = "Model for IndividualResults")
	@com.fasterxml.jackson.annotation.JsonProperty("individualResults")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.IndividualResults getIndividualResults() {
		return this.individualResults;
	}
	public void setIndividualResults(com.example.model.IndividualResults individualResults) {
		this.individualResults = individualResults;
	}
	
	/**
	 */
	public GreenIdData overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "overall")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	/**
	 */
	public GreenIdData registrationDetails(java.util.List<com.example.model.RegistrationDetails> registrationDetails) {
		setRegistrationDetails(registrationDetails);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "registrationDetails")
	@com.fasterxml.jackson.annotation.JsonProperty("registrationDetails")
	@javax.validation.Valid
	public java.util.List<com.example.model.RegistrationDetails> getRegistrationDetails() {
		return this.registrationDetails;
	}
	public void setRegistrationDetails(java.util.List<com.example.model.RegistrationDetails> registrationDetails) {
		this.registrationDetails = registrationDetails;
	}
	public GreenIdData addRegistrationDetail(com.example.model.RegistrationDetails registrationDetail) {
		if (this.registrationDetails == null) {
			this.registrationDetails = new java.util.ArrayList<com.example.model.RegistrationDetails>();
		}
		this.registrationDetails.add(registrationDetail);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		GreenIdData greenIdData = (GreenIdData) o;
		return java.util.Objects.equals(this.individualResults, greenIdData.individualResults)
				&& java.util.Objects.equals(this.overall, greenIdData.overall)
				&& java.util.Objects.equals(this.registrationDetails, greenIdData.registrationDetails);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.individualResults, this.overall, this.registrationDetails);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class GreenIdData {\n");
		
		sb.append("    individualResults: ").append(toIndentedString(this.individualResults)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("    registrationDetails: ").append(toIndentedString(this.registrationDetails)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
